@@ -174,12 +174,11 @@ tail.corpus <- function(x, n = 6L, ...) {
             metacorpus(c1, field) <- paste(metacorpus(c1, field), metacorpus(c2, field))
     }
     
-    row.names <- c(rownames(c1$documents), rownames(c2$documents))
-    c1$documents <- data.frame(
-        data.table::rbindlist(list(c1$documents, c2$documents), use.names = TRUE, fill = TRUE)
-    )
+    #rowname <- c(rownames(c1$documents), rownames(c2$documents))
+    c1$documents <- rbind(c1$documents, c2$documents)
+
     #  Put rownames back in because the hadleyverse discards them
-    rownames(c1$documents) <- make.unique(row.names, sep='')
+    #rownames(c1$documents) <- make.unique(rowname, sep='')
     
     # settings
     ### currently just use the c1 settings
