@@ -108,12 +108,10 @@ as.dfm.data.frame <- function(x) {
 }
 
 as_dfm_constructor <- function(x) {
-    new("dfmSparse", Matrix(as.matrix(x), 
-                            sparse = TRUE,
-                            dimnames = list(docs = if (is.null(rownames(x))) paste0(quanteda_options("base_docname"), seq_len(nrow(x))) else rownames(x),
-                                            features = if (is.null(colnames(x))) paste0(quanteda_options("base_featname"), seq_len(ncol(x))) else colnames(x)) 
-                            ) 
-        )
+    result <- new("dfmSparse", Matrix(as.matrix(x), sparse = TRUE))
+    dimnames(result) <- list(docs = if (is.null(rownames(x))) paste0(quanteda_options("base_docname"), seq_len(nrow(x))) else rownames(x),
+                             features = if (is.null(colnames(x))) paste0(quanteda_options("base_featname"), seq_len(ncol(x))) else colnames(x))
+    result
 }
 
 
