@@ -1,10 +1,3 @@
-# head
-# tail
-
-# kwic
-# 
-# char_tolower
-# char_toupper
 
 #' count the number of documents or features
 #' 
@@ -58,7 +51,7 @@ ndoc.tokenizedTexts <- function(x) {
 #' @details \code{nfeature} returns the number of features from a dfm; it is an
 #'   alias for \code{ntype} when applied to dfm objects.  This function is only 
 #'   defined for \link{dfm} objects because only these have "features".  (To count
-#'   tokens, see \code{\link{ntoken}})
+#'   tokens, see \code{\link{ntoken}}.)
 #' @export
 #' @seealso \code{\link{ntoken}}
 #' @examples
@@ -94,10 +87,10 @@ nfeature.tokens <- function(x) {
 #'   \link{tokens}, or \link{dfm} object
 #' @param ... additional arguments passed to \code{\link{tokens}}
 #' @note Due to differences between raw text tokens and features that have been 
-#'   defined for a \link{dfm}, the counts be different for dfm objects and the 
+#'   defined for a \link{dfm}, the counts may be different for dfm objects and the 
 #'   texts from which the dfm was generated.  Because the method tokenizes the 
 #'   text in order to count the tokens, your results will depend on the options 
-#'   passed through to \code{\link{tokens}}
+#'   passed through to \code{\link{tokens}}.
 #' @return count of the total tokens or types
 #' @details
 #' The precise definition of "tokens" for objects not yet tokenized (e.g.
@@ -142,7 +135,7 @@ ntoken.corpus <- function(x, ...) {
 #' @noRd
 #' @export
 ntoken.character <- function(x, ...) {
-    ntoken(tokenize(x, ...))
+    ntoken(tokens(x, ...))
 }
 
 #' @noRd
@@ -162,7 +155,7 @@ ntoken.tokenizedTexts <- function(x, ...) {
 #' @noRd
 #' @export
 ntype.character <- function(x, ...) {
-    ntype(tokenize(x, ...))
+    ntype(tokens(x, ...))
 }
 
 #' @noRd
@@ -191,13 +184,6 @@ ntoken.tokens <- function(x, ...) {
     lengths(x)
 }
 
-#' @export
-#' @noRd
-ntype.tokens <- function(x, ...) {
-    length(types(x))
-}
-
-
 #' count the number of sentences
 #' 
 #' Return the count of sentences in a corpus or character object.
