@@ -21,7 +21,7 @@ texts.readtext <- function(x, groups = NULL, ...) {
     if (!is.null(groups))
         stop("groups argument not supported for texts() on a readtext object")
     result <- x[["text"]]
-    names(result) <- row.names(x)
+    names(result) <- x[["doc_id"]]
     result
 }
 
@@ -30,13 +30,13 @@ texts.readtext <- function(x, groups = NULL, ...) {
 docvars.readtext <- function(x, field = NULL) {
     if (!is.null(field))
         warning("field argument not used for docvars on a readtext object", noBreaks. = TRUE)
-    as.data.frame(x[, -which(names(x)=="text"), drop = FALSE])
+    as.data.frame(x[, -which(names(x) %in% c("doc_id", "text")), drop = FALSE])
 }
 
 #' @noRd
 #' @export
 docnames.readtext <- function(x) {
-    row.names(x)
+    x[["doc_id"]]
 }
 
 #' @noRd
