@@ -274,20 +274,6 @@ escape_regex <- function(x){
     stri_replace_all_regex(x, "([.()^\\{\\}+$\\[\\]\\\\])", "\\\\$1") # allow glob
 }
 
-# which object class started the call stack?
-# @param x sys.calls() from inside a function
-# @param function_name the base name of the method of the function
-# @examples
-# who_called_me_first(sys.calls(), "dfm")
-who_called_me_first <- function(x, function_name) {
-    x <- as.character(x)
-    base_call_index <- which(stringi::stri_startswith_fixed(x, function_name))
-    base_call_index <- which(stringi::stri_detect_regex(x, paste0("^(quanteda::){0,1}", function_name, "(\\.\\w+){0,1}\\(")))
-    x <- x[base_call_index[-1]]
-    x <- stringi::stri_replace_all_regex(x, paste0(function_name, "\\.(\\w+)\\(.+$"), "$1")
-    x[1]
-}
-
 # function to check dots arguments against a list of permissible arguments
 check_dots <-  function(dots, permissible_args = NULL) {
     if (length(dots) == 0) return()
