@@ -184,7 +184,8 @@ List qatd_cpp_tokens_ngrams(const List &texts_,
     
     // Register both ngram (key) and unigram (value) IDs in a hash table
     MapNgrams map_ngram;
-
+    map_ngram.max_load_factor(GLOBAL_NGRAMS_MAX_LOAD_FACTOR);
+    
     //dev::Timer timer;
     //dev::start_timer("Ngram generation", timer);
 #if QUANTEDA_USE_TBB
@@ -217,7 +218,8 @@ List qatd_cpp_tokens_ngrams(const List &texts_,
     }
 #endif
     //dev::stop_timer("Token generation", timer);
-    return recompile(texts, types_ngram);
+    return recompile(texts, types_ngram, true, false, is_encoded(delim_) || is_encoded(types_));
+    //return recompile(texts, types_ngram);
 }
 
 
@@ -232,7 +234,8 @@ str(out)
 
 tok2 <- quanteda::tokens(data_corpus_inaugural)
 microbenchmark::microbenchmark(
-    qatd_cpp_tokens_ngrams(tok2, attr(tok2, 'types'), "-", 2, 1)
+    qatd_cpp_tokens_ngrams(tok2, attr(tok2, 'types'), "-", 2, 1),
+    tokenizers::tokenize_ngrams(texts(data_corpus_inaugural))
 )
 
 
