@@ -52,24 +52,24 @@ test_that("tokens_compound join a sequences of sequences", {
     toks <- tokens(txt)
     seqs <- tokens(c("a b", "b c d", "E F", "F G"), 
                    hash = FALSE, what = "fastestword")
-    expect_equivalent(
+    expect_equal(
         as.list(tokens_compound(toks, seqs, valuetype = "glob", case_insensitive = TRUE, join = TRUE)),
-        list(c("a_b_c_d", "e_f_g"),
-             c("A_B_C_D", "E_F_G"))
+        list(text1 = c("a_b_c_d", "e_f_g"),
+             text2 = c("A_B_C_D", "E_F_G"))
     )
     
-    expect_equivalent(
+    expect_equal(
         as.list(tokens_compound(toks, seqs, valuetype = "glob", case_insensitive = TRUE, join = FALSE)),
-        list(c("a_b", "b_c_d", "e_f", "f_g"),
-             c("A_B", "B_C_D", "E_F", "F_G"))
+        list(text1 = c("a_b", "b_c_d", "e_f", "f_g"),
+             text2 = c("A_B", "B_C_D", "E_F", "F_G"))
     )
     
     txts <- 'we like high quality sound'
-    seqs <- c('high quality', 'quality sound')
-    expect_equivalent(as.list(tokens_compound(tokens(txts), seqs, join = TRUE)),
-                      list(c("we", "like", "high_quality_sound")))
-    expect_equivalent(as.list(tokens_compound(tokenize(txts), seqs, join = FALSE)),
-                      list(c("we", "like", "high_quality", "quality_sound")))
+    seqs <- phrase(c('high quality', 'quality sound'))
+    expect_equal(as.list(tokens_compound(tokens(txts), seqs, join = TRUE)),
+                      list(text1 = c("we", "like", "high_quality_sound")))
+    expect_equal(as.list(tokens_compound(tokens(txts), seqs, join = FALSE)),
+                      list(text1 = c("we", "like", "high_quality", "quality_sound")))
     
 })
 
@@ -94,7 +94,86 @@ test_that("tokens_compound preserved document names", {
 test_that("tokens_compound works with padded tokens", {
     toks <- tokens(c(doc1 = 'a b c d e f g'))
     toks <- tokens_remove(toks, c('b', 'e'), padding = TRUE)
-    toks <- tokens_compound(toks, "c d")
+    toks <- tokens_compound(toks, phrase("c d"))
     expect_equal(sort(attr(toks, "types")),
                  sort(c("a", "c_d", "f", "g")))
 })
+
+test_that("tokens_compound works as expected with nested tokens", {
+
+    expect_equal(
+        as.character(tokens_compound(tokens("a b c d"), phrase(c("a b", "a b c")), 
+                     join = FALSE)),
+        c("a_b_c", "d")
+    )
+    expect_equal(
+        as.character(tokens_compound(tokens("a b c d"), phrase(c("a b", "a b c")), 
+                     join = TRUE)),
+        c("a_b_c", "d")
+    )
+})
+
+test_that("tokens_compound works as expected with nested and overlapping tokens", {
+
+    expect_equal(
+        as.character(tokens_compound(tokens("a b c d e"), 
+                                     phrase(c("a b", "a b c", "c d")),
+                                     join = FALSE)),
+        c("a_b_c", "c_d", "e")
+    )
+    expect_equal(
+        as.character(tokens_compound(tokens("a b c d e"), 
+                                     phrase(c("a b", "a b c", "c d")),
+                                     join = TRUE)),
+        c("a_b_c_d", "e")
+    )
+})
+
+test_that("tokens_compound works as expected with collocations", {
+    cols <- textstat_collocations(tokens("capital gains taxes are worse than inheritance taxes"),
+                                  size = 2, min_count = 1)
+    toks <- tokens("The new law included capital gains taxes and inheritance taxes.")
+    
+    expect_equal(
+        as.character(tokens_compound(toks, phrase(cols), join = FALSE))[c(5, 6, 8)],
+        c("capital_gains", "gains_taxes", "inheritance_taxes")
+    )
+    expect_equal(
+        as.character(tokens_compound(toks, phrase(cols), join = TRUE))[c(5, 7)],
+        c("capital_gains_taxes", "inheritance_taxes")
+    )
+
+    expect_equal(
+         tokens_compound(toks, cols),
+         tokens_compound(toks, phrase(cols))
+     )
+    expect_equal(
+        tokens_compound(toks, cols, join = TRUE),
+        tokens_compound(toks, phrase(cols), join = TRUE)
+    )
+})
+
+test_that("tokens_compound works as expected with dictionaries", {
+    dict <- dictionary(list(taxcgt = c("capital gains tax*"), taxit = "inheritance tax*"))
+    toks <- tokens("The new law included capital gains taxes and inheritance taxes.")
+    expect_equal(
+        as.character(tokens_compound(toks, dict))[c(5, 7)],
+        c("capital_gains_taxes", "inheritance_taxes")
+    )
+    expect_equal(
+        tokens_compound(toks, dict),
+        tokens_compound(toks, phrase(dict))
+    )
+    
+    dict <- dictionary(list(tax1 = c("capital gains", "taxes"), 
+                            tax2 = "gains taxes"))
+    expect_equal(
+        as.character(tokens_compound(toks, dict, join = TRUE))[5],
+        c("capital_gains_taxes")
+    )
+    expect_equal(
+        as.character(tokens_compound(toks, dict, join = FALSE))[5:6],
+        c("capital_gains", "gains_taxes")
+    )
+})
+
